@@ -1,5 +1,4 @@
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
-# All Rights Reserved.
 #
 # This program is Free Software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,7 +25,7 @@ from enum import Enum
 from pathlib import Path
 from shutil import which
 from textwrap import dedent, indent, shorten
-from typing import ContextManager, Iterator
+from typing import ContextManager, Iterable, Iterator, cast
 from unittest.mock import patch
 
 if sys.version_info >= (3, 8):
@@ -37,7 +36,7 @@ else:
 from boltons.iterutils import flatten
 from boltons.strutils import strip_ansi
 from click_extra.colorize import default_theme as theme
-from click_extra.platform import CURRENT_OS_ID, is_linux
+from click_extra.platforms import Group, Platform, current_os, is_linux
 from click_extra.run import (
     INDENT,
     Arg,
@@ -154,6 +153,18 @@ class MetaPackageManager(type):
         if "virtual" not in dct:
             cls.virtual = name == "PackageManager" or not cls.cli_names
 
+        # Normalize list of platform and groups into a frozen set of platforms.
+        if "platforms" in dct:
+            platforms = set()
+            for spec in flatten([dct["platforms"]]):
+                if isinstance(spec, Platform):
+                    platforms.add(spec)
+                elif isinstance(spec, Group):
+                    platforms |= spec.platforms
+                else:
+                    raise ValueError(f"Unrecognized platform specifier: {spec!r}")
+            cls.platforms = frozenset(platforms)
+
 
 def highlight_cli_name(
     path: Path | None, match_names: tuple[str, ...] | None = None
@@ -216,8 +227,14 @@ class PackageManager(metaclass=MetaPackageManager):
     homepage_url: str | None = None
     """Home page of the project, only used in documentation for reference."""
 
-    platforms: frozenset = frozenset()
-    """List of platforms supported by the manager."""
+    platforms: Group | Platform | Iterable[Group | Platform] | frozenset[
+        Platform
+    ] = frozenset()
+    """List of platforms supported by the manager.
+
+    Allows for a mishmash of platforms and groups. Will be normalized into a frozen set of
+    ``Platform`` instances at instanciation.
+    """
 
     requirement: str | None = None
     """Minimal required version.
@@ -247,7 +264,7 @@ class PackageManager(metaclass=MetaPackageManager):
     cli_search_path: tuple[str, ...] = ()
     """ List of additional path to help :program:`mpm` hunt down the package manager CLI.
 
-    Should be a list of strings whose order dictatate the search sequence.
+    Must be a list of strings whose order dictates the search sequence.
 
     Most of the time unnecessary: :py:func:`meta_package_manager.base.PackageManager.cli_path`
     works well on all platforms.
@@ -450,7 +467,9 @@ class PackageManager(metaclass=MetaPackageManager):
     @cached_property
     def supported(self) -> bool:
         """Is the package manager supported on that platform?"""
-        return CURRENT_OS_ID in self.platforms
+        # At this point self.platforms is normalized as a frozenset of Platform
+        # instances, but mypy doens't know it.
+        return current_os() in self.platforms  # type: ignore[operator]
 
     @cached_property
     def executable(self) -> bool:
