@@ -242,6 +242,8 @@ compared_gt = (
     # ("6.2", "6.2.0"),
     # ("9.52", "9d"),
     ("8.2p1_1", "8.2p1"),
+    ("3.12.0a4", "3.7.0"),
+    # ("3.12.0", "3.12.0a4"),
     # ("3.7.7", "3.7-beta2_1"),
     # ("2.1.1", "2.1.1-git-23hfb2-foobar"),
     (20200313, 20190801),
